interactive_media_ads library
Classes
- Ad
- Data object representing a single ad.
- AdDisplayContainer
- A Widget for displaying loaded ads.
- AdError
- Surfaces an error that occurred during ad loading or playing.
- AdErrorEvent
- An event raised when there is an error loading or playing ads.
- AdEvent
- Simple data class used to transport ad playback information.
- AdPodInfo
- Simple data object containing podding metadata.
- AdsLoader
- Allows publishers to request ads from ad servers or a dynamic ad insertion stream.
- AdsLoadErrorData
- Ad error data that is returned when the ads loader fails to load the ad.
- AdsManager
- Handles playing ads after they've been received from the server.
- AdsManagerDelegate
- Delegate for ad events or errors that occur during ad or stream initialization and playback.
- AdsRenderingSettings
- Defines parameters that control the rendering of ads.
- AdsRequest
- An object containing the data used to request ads from the server.
- AndroidInteractiveMediaAds
-
Android implementation of
InteractiveMediaAdsPlatform. - CompanionAd
- An object that holds data corresponding to the companion Ad.
- CompanionAdSlot
- Ad slot for companion ads.
- CompanionAdSlotSize
- The size of the slot for a companion ad.
- CompanionAdSlotSizeFixed
- A slot for a companion ad with a fixed with and height.
- CompanionAdSlotSizeFluid
- A slot for a companion had with no fixed size, but rather adapts to fit the creative content they display.
- ContentProgressProvider
- Allow the SDK to track progress of the content video.
- ImaSettings
- Defines general SDK settings that are used when creating an AdsLoader.
- IOSInteractiveMediaAds
-
Implementation of
InteractiveMediaAdsPlatformfor iOS. - OnAdsLoadedData
- Data when ads are successfully loaded from the ad server through an AdsLoader.
- UniversalAdId
- Simple data object containing universal ad ID information.
Enums
- AdErrorCode
- The types of errors that can be encountered when loading an ad.
- AdErrorType
- Possible error types while loading or playing ads.
- AdEventType
- Types of events that can occur during ad playback.
- AdUIElement
- Describes an element of the ad UI, to be requested or rendered by the SDK.