AdsRequest class

An object containing the data used to request ads from the server.

Constructors

AdsRequest({required String adTagUrl, ContentProgressProvider? contentProgressProvider, bool? adWillAutoPlay, bool? adWillPlayMuted, bool? continuousPlayback, Duration? contentDuration, List<String>? contentKeywords, String? contentTitle, Duration? liveStreamPrefetchMaxWaitTime, Duration? vastLoadTimeout})
Creates an AdsRequest with the given ad tag URL.
AdsRequest.fromPlatform(PlatformAdsRequest platform)
Constructs an AdsRequest from a specific platform implementation.
AdsRequest.withAdsResponse({required String adsResponse, ContentProgressProvider? contentProgressProvider, bool? adWillAutoPlay, bool? adWillPlayMuted, bool? continuousPlayback, Duration? contentDuration, List<String>? contentKeywords, String? contentTitle, Duration? liveStreamPrefetchMaxWaitTime, Duration? vastLoadTimeout})
Creates an AdsRequest with the given canned ads response.

Properties

adsResponse String?
Specifies a VAST, VMAP, or ad rules response to be used instead of making a request through an ad tag URL.
no setter
adTagUrl String?
The URL from which ads will be requested.
no setter
adWillAutoPlay bool?
Notifies the SDK whether the player intends to start the content and ad in response to a user action or whether it will be automatically played.
no setter
adWillPlayMuted bool?
Notifies the SDK whether the player intends to start the content and ad while muted.
no setter
contentDuration Duration?
Specifies the duration of the content to be shown.
no setter
contentKeywords List<String>?
Specifies the keywords used to describe the content to be shown.
no setter
contentProgressProvider ContentProgressProvider?
A ContentProgressProvider instance to allow scheduling of ad breaks based on content progress (cue points).
no setter
contentTitle String?
Specifies the title of the content to be shown.
no setter
continuousPlayback bool?
Notifies the SDK whether the player intends to continuously play the content videos one after another similar to TV broadcast.
no setter
hashCode int
The hash code for this object.
no setterinherited
liveStreamPrefetchMaxWaitTime Duration?
Specifies the maximum amount of time to wait, after calling requestAds, before requesting the ad tag URL.
no setter
platform → PlatformAdsRequest
Implementation of PlatformAdsRequest for the current platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vastLoadTimeout Duration?
Specifies the VAST load timeout in milliseconds for a single wrapper.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited