CompanionAdSlotSize class sealed

The size of the slot for a companion ad.

Implementers
Annotations

Constructors

CompanionAdSlotSize.fixed({required int width, required int height})
A slot for a companion ad with a fixed with and height.
factory
CompanionAdSlotSize.fluid()
A slot for a companion ad with no fixed size, but rather adapts to fit the creative content they display.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited